@@ -66,22 +66,8 @@ class Client(object):
     def lpush(self, key, value):
         self.queues[key].put_nowait(value)
 
-    def parse_command(self, cmd):
-        c = cmd.split('\r\n')
-        c.pop()
-        c.reverse()
-        argv = []
-        argc = int(c.pop().replace('*', ''))
-        for i in xrange(argc):
-            c.pop()
-            argv.append(c.pop())
-        return argv
-
-    def parse_response(self, type, **options):
-        cmd = self.connection._sock.data.pop()
-        argv = self.parse_command(cmd)
-        cmd = argv[0]
-        queues = argv[1:-1]
+    def parse_response(self, connection, type, **options):
+        cmd, queues = self.connection._sock.data.pop()
         assert cmd == type
         self.connection._sock.data = []
         if type == "BRPOP":
@@ -141,12 +127,15 @@ class Client(object):
         def disconnect(self):
             self.disconnected = True
 
-        def send(self, cmd, client):
-            self._sock.data.append(cmd)
+        def send_command(self, cmd, *args):
+            self._sock.data.append((cmd, args))
 
     def info(self):
         return {"foo": 1}
 
+    def pubsub(self, *args, **kwargs):
+        return self
+
     @property
     def connection(self):
         if self._connection is None:
