@@ -13,7 +13,7 @@ import socket
 try:
     from ssl import SSLError
 except ImportError:
-    class SSLError(Exception):
+    class SSLError(Exception):  # noqa
         pass
 
 from amqplib import client_0_8 as amqp
@@ -173,7 +173,7 @@ class Message(base.Message):
                 **kwargs)
 
 
-class Channel(_Channel):
+class Channel(_Channel, base.StdChannel):
     Message = Message
     events = {"basic_return": []}
 
@@ -231,11 +231,14 @@ class Transport(base.Transport):
             conninfo.userid = "guest"
         if conninfo.password is None:
             conninfo.password = "guest"
+        if conninfo.login_method is None:
+            conninfo.login_method = "AMQPLAIN"
         if not conninfo.port:
             conninfo.port = self.default_port
         conn = self.Connection(host=conninfo.host,
                                userid=conninfo.userid,
                                password=conninfo.password,
+                               login_method=conninfo.login_method,
                                virtual_host=conninfo.virtual_host,
                                insist=conninfo.insist,
                                ssl=conninfo.ssl,
