@@ -10,19 +10,19 @@ Pika transport.
 """
 import socket
 
-import pika
+from kombu.exceptions import VersionMismatch
+from kombu.transport import base
+
+from pika import channel  # must be here to raise importerror for below.
 try:
     from pika import asyncore_adapter
 except ImportError:
-    raise ImportError("Kombu only works with pika version 0.5.2")
+    raise VersionMismatch("Kombu only works with pika version 0.5.2")
 from pika import blocking_adapter
-from pika import channel
 from pika import connection
 from pika import exceptions
 from pika.spec import Basic, BasicProperties
 
-from kombu.transport import base
-
 DEFAULT_PORT = 5672
 
 
@@ -46,7 +46,7 @@ class Message(base.Message):
         super(Message, self).__init__(channel, **kwargs)
 
 
-class Channel(channel.Channel):
+class Channel(channel.Channel, base.StdChannel):
     Message = Message
 
     def basic_get(self, queue, no_ack):
@@ -153,7 +153,8 @@ class AsyncoreConnection(asyncore_adapter.AsyncoreConnection):
 class SyncTransport(base.Transport):
     default_port = DEFAULT_PORT
 
-    connection_errors = (exceptions.ConnectionClosed,
+    connection_errors = (socket.error,
+                         exceptions.ConnectionClosed,
                          exceptions.ChannelClosed,
                          exceptions.LoginError,
                          exceptions.NoFreeChannels,
